@@ -71,14 +71,6 @@ public class DataSourceRealm extends RealmBase {
     protected boolean localDataSource = false;
 
 
-    /**
-     * Descriptive information about this Realm implementation.
-     * @deprecated This will be removed in Tomcat 9 onwards.
-     */
-    @Deprecated
-    protected static final String name = "DataSourceRealm";
-
-
     /**
      * The column in the user role table that names a role
      */
@@ -346,7 +338,7 @@ public class DataSourceRealm extends RealmBase {
         ArrayList<String> list = getRoles(dbConnection, username);
 
         // Create and return a suitable Principal for this user
-        return new GenericPrincipal(username, credentials, list);
+        return new GenericPrincipal(username, list);
     }
 
 
@@ -407,12 +399,6 @@ public class DataSourceRealm extends RealmBase {
         return null;
     }
 
-    @Override
-    @Deprecated
-    protected String getName() {
-        return name;
-    }
-
     /**
      * @return the password associated with the given principal's user name.
      */
@@ -474,11 +460,10 @@ public class DataSourceRealm extends RealmBase {
     protected Principal getPrincipal(String username) {
         Connection dbConnection = open();
         if (dbConnection == null) {
-            return new GenericPrincipal(username, null, null);
+            return new GenericPrincipal(username, null);
         }
         try {
             return new GenericPrincipal(username,
-                    getPassword(dbConnection, username),
                     getRoles(dbConnection, username));
         } finally {
             close(dbConnection);
